@@ -12,6 +12,7 @@ def make(
         scriptname=None,
         runscript=False,
         replace=False,
+        multiprocess=False,
 ):
     if not os.path.exists(srcdir):
         raise ValueError(
@@ -39,7 +40,7 @@ def make(
                 os.makedirs(pathexist)
             if os.path.exists(linkpath):
                 if not replace:
-                    log.error(
+                    log.warn(
                         '{linkpath} already exists. Not linking.'.format(
                             linkpath=linkpath,
                         )
@@ -62,6 +63,15 @@ def make(
             scriptdir = os.path.dirname(scriptsrc)
             scripttail = os.path.relpath(scriptdir, srcdir)
             scriptdst = os.path.join(linkdir, scripttail)
+            name = os.path.basename(scriptsrc)
+            name = os.path.join(scripttail, name)
             if not os.path.exists(scriptdst):
                 os.makedirs(scriptdst)
-            script.runscript(scriptsrc, srcdir, linkdir, scripttail)
+            script.runscript(
+                scriptsrc,
+                srcdir,
+                linkdir,
+                scripttail,
+                name=name,
+                multiprocess=multiprocess,
+            )
