@@ -238,7 +238,7 @@ def test_make_linkdir_has_file(srcdir, linkdir, fakelog):
         srcdir=srcdir,
         linkdir=linkdir,
     )
-    error = mock.call.error(
+    error = mock.call.warn(
         '{linkfile} already exists. Not linking.'.format(
             linkfile=linkfile,
         ),
@@ -257,7 +257,7 @@ def test_make_linkdir_has_link(srcdir, linkdir, fakelog):
         srcdir=srcdir,
         linkdir=linkdir,
     )
-    error = mock.call.error(
+    error = mock.call.warn(
         '{linkfile} already exists. Not linking.'.format(
             linkfile=linkfile,
         ),
@@ -440,6 +440,8 @@ def test_make_script_simple(srcdir, linkdir, fakerun):
         srcdir,
         linkdir,
         '.',
+        name='./foo-script',
+        multiprocess=False,
         )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == []
@@ -465,6 +467,8 @@ def test_make_script_many_files(srcdir, linkdir, fakerun):
         srcdir,
         linkdir,
         '.',
+        name='./foo-script',
+        multiprocess=False,
         )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == ['foo']
@@ -492,6 +496,8 @@ def test_make_script_nested_dir(srcdir, linkdir, fakerun):
         srcdir,
         linkdir,
         'foo',
+        name='foo/bar-script',
+        multiprocess=False,
         )
     assert fakerun.mock_calls == [run]
     assert os.listdir(linkdir) == ['foo']
@@ -518,12 +524,16 @@ def test_make_script_many_scripts(srcdir, linkdir, fakerun):
         srcdir,
         linkdir,
         '.',
+        name='./bar-script',
+        multiprocess=False,
         )
     runnested = mock.call(
         scriptnested,
         srcdir,
         linkdir,
         'foo',
+        name='foo/bar-script',
+        multiprocess=False,
         )
     calls = [
         run,
@@ -561,3 +571,27 @@ def test_make_script_no_run_nested(srcdir, linkdir, fakerun):
     )
     assert fakerun.mock_calls == []
     assert os.listdir(linkdir) == []
+
+@tempdirs.makedirs(2)
+@mock.patch('linkins.script.runscript')
+def test_make_script_multiprocess(srcdir, linkdir, fakerun):
+    scriptfile = os.path.join(srcdir, 'foo-script')
+    with open(scriptfile, 'w') as fp:
+        fp.write('script content')
+    link.make(
+        srcdir=srcdir,
+        linkdir=linkdir,
+        scriptname='foo-script',
+        runscript=True,
+        multiprocess=True,
+    )
+    run = mock.call(
+        scriptfile,
+        srcdir,
+        linkdir,
+        '.',
+        name='./foo-script',
+        multiprocess=True,
+        )
+    assert fakerun.mock_calls == [run]
+    assert os.listdir(linkdir) == []
